==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/Sundance/src-solvers/LinearSolvers/TSFBICGSTABSolverDecl.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
 /* @HEADER@ */

#ifndef TSFBICGSTABSOLVER_DECL_HPP
#define TSFBICGSTABSOLVER_DECL_HPP

#include "SundanceDefs.hpp"
#include "TSFKrylovSolver.hpp"
#include "SundanceHandleable.hpp"
#include "SundancePrintable.hpp"
#include "SundanceOut.hpp"
#include "Teuchos_Describable.hpp"


namespace TSFExtended
{
using namespace Teuchos;
using namespace SundanceUtils;
/**
 *
 */
template <class Scalar>
class BICGSTABSolver : public KrylovSolver<Scalar>,
                       public SundanceUtils::Handleable<LinearSolverBase<Scalar> >,
                       public Printable,
                       public Describable
{
public:
  /** */
  BICGSTABSolver(const ParameterList& params = ParameterList());

  /** */
  BICGSTABSolver(const ParameterList& params,
    const PreconditionerFactory<Scalar>& precond);

  /** */
  virtual ~BICGSTABSolver(){;}

  /** \name Printable interface */
  //@{
  /** Write to a stream  */
  void print(std::ostream& os) const ;
  //@}
    
  /** \name Describable interface */
  //@{
  /** Write a brief description */
  string description() const {return "BICGSTABSolver";}
  //@}

  /** \name Handleable interface */
  //@{
  /** Return a ref count pointer to a newly created object */
  virtual RefCountPtr<LinearSolverBase<Scalar> > getRcp() 
    {return rcp(this);}
  //@}
    
protected:

  /** */
  virtual SolverState<Scalar> solveUnprec(const LinearOperator<Scalar>& op,
    const Vector<Scalar>& rhs,
    Vector<Scalar>& soln) const ;

    
};


}

#endif

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/Sundance/src-solvers/LinearSolvers/TSFBICGSTABSolverDecl.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
 /* @HEADER@ */

#ifndef TSFBICGSTABSOLVER_DECL_HPP
#define TSFBICGSTABSOLVER_DECL_HPP

#include "SundanceDefs.hpp"
#include "TSFKrylovSolver.hpp"
#include "SundanceHandleable.hpp"
#include "SundancePrintable.hpp"
#include "SundanceOut.hpp"
#include "Teuchos_Describable.hpp"


namespace TSFExtended
{
using namespace Teuchos;
using namespace Sundance;
/**
 *
 */
template <class Scalar>
class BICGSTABSolver : public KrylovSolver<Scalar>,
                       public Sundance::Handleable<LinearSolverBase<Scalar> >,
                       public Printable,
                       public Describable
{
public:
  /** */
  BICGSTABSolver(const ParameterList& params = ParameterList());

  /** */
  BICGSTABSolver(const ParameterList& params,
    const PreconditionerFactory<Scalar>& precond);

  /** */
  virtual ~BICGSTABSolver(){;}

  /** \name Printable interface */
  //@{
  /** Write to a stream  */
  void print(std::ostream& os) const ;
  //@}
    
  /** \name Describable interface */
  //@{
  /** Write a brief description */
  string description() const {return "BICGSTABSolver";}
  //@}

  /** \name Handleable interface */
  //@{
  /** Return a ref count pointer to a newly created object */
  virtual RCP<LinearSolverBase<Scalar> > getRcp() 
    {return rcp(this);}
  //@}
    
protected:

  /** */
  virtual SolverState<Scalar> solveUnprec(const LinearOperator<Scalar>& op,
    const Vector<Scalar>& rhs,
    Vector<Scalar>& soln) const ;

    
};


}

#endif
